@@ -356,10 +356,10 @@ def _configure_dapr_app(_app, function, ctx: FunctionContext):
     if inputs is not None:
         for input in inputs.values():
             if input.type == _DAPR_BINDINGS:
-                function = _app.binding(input.component)(function)
+                _app.binding(input.component)(function)
                 print("binding {}".format(input.component))
             elif input.type == _DAPR_PUBSUB:
-                function = _app.subscribe(topic=input.uri, pubsub_name=input.component)(function)
+                _app.subscribe(topic=input.uri, pubsub_name=input.component)(function)
                 print("sub topic {}, pubsub name {}".format(input.uri, input.component))
             else:
                 raise InvalidFuncContextInputType(
